@@ -3,20 +3,23 @@
 #include <stdarg.h>
 #include "tree-vect.h"
 
-typedef char achar __attribute__ ((__aligned__(16)));
-
 #define N 16
  
+char x[N] __attribute__ ((__aligned__(16)));
+char cb[N] __attribute__ ((__aligned__(16))) = {0,3,6,9,12,15,18,21,24,27,30,33,36,39,42,45};
+
+__attribute__ ((noinline))
 int main1 ()
 {  
   struct {
-    achar *p;
-    achar *q;
+    char *p;
+    char *q;
   } s;
   int i;
-  achar x[N];
-  achar cb[N] = {0,3,6,9,12,15,18,21,24,27,30,33,36,39,42,45};
 
+  /* Check that datarefs analysis can determine that the access via pointer
+     s.p is based off array x, which enables us to antialias this access from
+     the access to array cb.  */
   s.p = x;
   for (i = 0; i < N; i++)
     {
@@ -30,6 +33,9 @@ int main1 ()
         abort ();
     }
 
+  /* Check that datarefs analysis can determine that the access via pointer
+     s.p is based off array x, and that the access via pointer s.q is based off
+     array cb, which enables us to antialias these two accesses.  */
   s.q = cb;
   for (i = 0; i < N; i++)
     {
